@@ -1,5 +1,6 @@
 import os
 from beanstalk.tasks.action import check_comments
+from beanstalk.tasks.action.django import collect_static
 
 # Beanstalk tool behavior
 #-----------------------------------------------------------------------------------------------------------------------
@@ -17,9 +18,11 @@ CHECK_FIX_ME = True
 SOURCE_CHECK_ACTIONS = [
     check_comments,
 ]
-PRE_DEPLOY_ACTIONS = []
+PRE_DEPLOY_ACTIONS = [
+    collect_static,
+]
 PRE_INSTALL_ACTIONS = []
-POST_RSYNC_ACTIONS = []
+POST_SEND_ACTIONS = []
 POST_INSTALL_ACTIONS = []
 POST_DEPLOY_ACTIONS = []
 
