@@ -183,6 +183,8 @@ def deploy(settings_path=None, **settings_patches):
             if run_hooked_actions('POST_DEPLOY_ACTIONS'):
                 print ''
 
+            print green('Deployed!')
+
 
 @roles('web_servers')
 @beanstalk_role('app')
@@ -200,7 +202,7 @@ def deploy_remote_core():
                 'Please setup beanstalk-stack on this server first.'
             )
         remote_bs_version = json.loads(run('bsjack info.version:USE_JSON=True --hide=status'))
-        if beanstalk.VERSION != (remote_bs_version['list']):
+        if beanstalk.VERSION != tuple(remote_bs_version['list']):
             abort(red('Hey! Jack at the remote is not the same as me. He\'s %s. But I\'m %s.') %
                   (remote_bs_version['string'], beanstalk.__version__))
 
