@@ -54,9 +54,9 @@ def set_verbose_level(verbose_level=None):
     if verbose_level == 0:
         hide_output_status = ['everything']
     elif verbose_level == 1:
-        hide_output_status = ['status', 'stdout', 'stderr']
+        hide_output_status = ['status', 'stdout', 'stderr', 'running']
     elif verbose_level == 2:
-        hide_output_status = ['status']
+        hide_output_status = ['status', 'running']
     else:
         hide_output_status = []
 
